/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/

#ifndef _U2_WMETADIALOG_H_
#define _U2_WMETADIALOG_H_

#include "ui/ui_WorkflowMetaDialog.h"

#include <U2Lang/ActorModel.h>
#include <U2Lang/Schema.h>

namespace U2 {
using namespace Workflow;
class WorkflowMetaDialog : public QDialog, public Ui_WorkflowMetaDialog {
    Q_OBJECT

public:
    WorkflowMetaDialog(const Workflow::Metadata& meta);

public:
    Workflow::Metadata meta;

private slots:
   
    void sl_onBrowse();
    void sl_onSave();
    void sl_onURLChanged(const QString & text);
};

}//namespace

#endif
